//-------------------------------------------------------------------------------------------------------------------------------
{Procedury formulare - zobrazeni seznamu typu map daneho zdroje}
procedure form_MapSel(Sender: TObject);
var
  MapConfig_db : TSqliteDatabase; // databaze se strukturou map (map-config.xml) 
  Map_ID       : String; 
  MapConfig    : TSqliteTable;    // tabulka map
begin
  MapForm_btn_ImpOzi    .Enabled := False;
  MapForm_btn_ImpMobac  .Enabled := False;
  MapForm_btn_ImpGeokuk .Enabled := False;
  with MapForm_lb_MapType do begin
    Items.Clear;
    ItemIndex := -1;
    MapConfig_db := TSqliteDatabase.Create(MakroPath + 'Data\map-config.db3');
    try
      MultiSelect := RegexFind('(M|m)apy(C|c)z', MapForm_lb_Map.Items[MapForm_lb_Map.ItemIndex]); 
      Map_ID := RegexExtract('\d+$', MapForm_lb_Map.Items[MapForm_lb_Map.ItemIndex]);
      if SQLTableExists(MapConfig_db, 'map_type') then begin
        MapConfig := MapConfig_db.GetTable('SELECT * FROM map_type WHERE key="' + Map_ID + '" ORDER BY name ASC' , false);  //
        try
          while not MapConfig.EOF do begin
            Items.Add(SetLen(UtfToAnsi(MapConfig.FieldAsString(1)),16) + SetLen(MapConfig.FieldAsString(3),7) + MapConfig.FieldAsString(2));
            MapConfig.next;                   // skok na dalsi
          end;
        finally
          MapConfig.free;
        end;
      end;
    finally
      MapConfig_db.free;
    end;
  end;
end;
//-------------------------------------------------------------------------------------------------------------------------------
{Procedury formulare - aktivuje prislusna tlacitka}
procedure form_MapTypeSel(Sender: TObject);
var
  cond : Boolean;
begin
  cond := ((MapForm_lb_MapType.SelCount  >  0) and     MapForm_lb_MapType.Multiselect) OR
          ((MapForm_lb_MapType.ItemIndex > -1) and not MapForm_lb_MapType.Multiselect) ;    //povoli tlacitka pouze kdyz je vybrany nejaky typ mapy
  if RegexFind('(g|G)oogle', MapForm_lb_Map.Items[MapForm_lb_Map.ItemIndex]) then begin 
    MapForm_btn_ImpOzi   .Enabled := cond;
    MapForm_btn_ImpMobac .Enabled := cond;
    MapForm_btn_ImpGeokuk.Enabled := False;
  end
  else begin
    MapForm_btn_ImpOzi   .Enabled := False;
    MapForm_btn_ImpMobac .Enabled := False;
    MapForm_btn_ImpGeokuk.Enabled := cond;
  end;
end;
//-------------------------------------------------------------------------------------------------------------------------------
{Map Form Active/Inactive}
procedure form_MapInh(Active: Boolean);
begin
  MapForm_btn_Refresh       .Enabled :=  Active;
  MapForm_btn_Close         .Enabled :=  Active;
  MapForm_lb_Map            .Enabled :=  Active;
  MapForm_lb_MapType        .Enabled :=  Active;
  MapForm_lbl_Disc          .Enabled :=  Active;
  MapForm_ed_PD_Disc        .Enabled :=  Active;
  MapForm_ed_OziPath        .Enabled :=  Active;
  MapForm_ed_MobacPath      .Enabled :=  Active;
  MapForm_ed_GeokukPath     .Enabled :=  Active;
  MapForm_btn_SelDisc       .Enabled :=  Active;
  MapForm_btn_SelOziPath    .Enabled :=  Active;
  MapForm_btn_SelMobacPath  .Enabled :=  Active;
  MapForm_cb_Geokuk_Del     .Enabled :=  Active;
  if Active and (MapForm_lb_Map.ItemIndex > -1) then begin
    form_MapTypeSel(MapForm_lb_MapType);
  end
  else begin
    MapForm_btn_ImpOzi        .Enabled :=  False;
    MapForm_btn_ImpMobac      .Enabled :=  False;
    MapForm_btn_ImpGeokuk     .Enabled :=  False;
  end;
end;
//-------------------------------------------------------------------------------------------------------------------------------
{Read map-config.xml}      //nacte do databaze seznam definovanych map v map-config.xml
procedure ReadMapConfig(MapConfigFileName: String);
var  
  MapConfig_db                  : TSqliteDatabase; // databaze seznamu map 
  xml                           : String;
  MapSource, MapSourceCache     : String;
  mskey,mstype,msname,msstorage : String;
  MapType, MapTypeCache         : String;
  mtname,mtfile,mtmode          : String;
  j                             : integer;
begin
  if FileExists(MapConfigFileName) then begin 
    xml := FileToString(MapConfigFileName);
    MapConfig_db := TSqliteDatabase.Create(MakroPath + 'Data\Map-config.db3');
    try
      j := 0;
      repeat
        if GB_Test then Break; //preruseno uzivatelem
        j := j + 1; 
        GB_Progress(2, j-1 ,j);
        MapSource := fetch(xml, '</MapSource>'); MapSourceCache := MapSource;
        MapType := fetch(MapSource, '<MapType');   //poprve ukosnout pocatecni tagy
        mstype    := RegExSubstitute('<type>(.*?)</type>'      , MapType, '$1');
        msname    := RegExSubstitute('<name>(.*?)</name>'      , MapType, '$1');
        msstorage := Lowercase(RegExSubstitute('<storage>(.*?)</storage>', MapType, '$1')); if msstorage = '' then msstorage := 'filesystem';
        MapConfig_db.ExecSQL('BEGIN TRANSACTION');
        if (mstype <> '') and (msname <> '') then begin
          mskey := MapConfig_db.GetTableString('SELECT key FROM map_source WHERE type="'+mstype+'" AND name="'+msname+'" AND storage="'+msstorage+'"');
          if mskey = '' then begin 
            MapConfig_db.ExecSQL('INSERT INTO map_source (type,name,storage) VALUES ("' + mstype + '","' + msname + '","' + msstorage + '")');
            mskey := MapConfig_db.GetTableString('SELECT seq FROM sqlite_sequence WHERE name="map_source"');
          end;
          repeat
            MapType := fetch(MapSource, '</MapType>'); MapTypeCache := MapType;
            mtname  := RegExSubstitute('<name>(.*?)</name>', MapType, '$1');
            mtfile  := Lowercase(RegExSubstitute('<file>(.*?)</file>', MapType, '$1')); 
            mtmode  := Lowercase(RegExSubstitute('mode="(.*?)">'     , MapType, '$1'));
            if (mtname <> '') and (mtfile <> '') then begin
              MapConfig_db.ExecSQL('INSERT OR REPLACE INTO map_type (key,name,file,mode) VALUES ("' + mskey + '","' + mtname + '","' + mtfile + '","' + mtmode + '")');
            end;
          until (MapTypeCache = '')            
        end;
        MapConfig_db.ExecSQL('COMMIT');
      until (MapSourceCache = '')
    finally
      MapConfig_db.free;
    end;
    GB_Progress(2, 0 ,100);
  end
  else begin
    ShowMessage(_('File not found:') + CRLF + MapConfigFileName + CRLF + CRLF +
                _('If you use Off Line mode or External disc mode, ')+
                _('you have to connect device at least once by ActiveSync mode before ')+
                _('and then upload settings.'));
  end;
end;
//-------------------------------------------------------------------------------------------------------------------------------
{Read Maps from map-config.db3}
procedure form_MapRead(Sender: TObject);
var  
  MapConfig_db        : TSqliteDatabase; // databaze seznamu map 
  Map                 : TSqliteTable;    // tabulka map
begin
  form_MapInh(False);
  GB_Progress(1, 10 ,100);
  with MapForm_lb_Map do begin
    Items.Clear;
    MapForm_lb_MapType.Items.Clear;
    Sorted := False;
    MapConfig_db := TSqliteDatabase.Create(MakroPath + 'Data\Map-config.db3');
    try
      if SQLTableExists(MapConfig_db, 'map_source') then begin
        case TBitBtn(Sender).Name of       // nacte tabulku stop dle zvoleneho razeni
          'btn_ArrDate_Dwn': Map := MapConfig_db.GetTable('SELECT * FROM map_source ORDER BY name ASC' , false);
          'btn_ArrID_Dwn'  : Map := MapConfig_db.GetTable('SELECT * FROM map_source ORDER BY key  ASC' , false);
          'btn_ArrID_Up'   : Map := MapConfig_db.GetTable('SELECT * FROM map_source ORDER BY key  DESC', false);
          else               Map := MapConfig_db.GetTable('SELECT * FROM map_source ORDER BY type ASC' , false);
        end;
        try
          while not Map.EOF do begin
            Items.Add(SetLen(UtfToAnsi(Map.FieldAsString(2)),30) + SetLen(Map.FieldAsString(1),6) + SetLen(Map.FieldAsString(3),10) + Map.FieldAsString(0));
            Map.next;                   // skok na dalsi
          end;
        finally
          Map.free;
        end;
      end
      else Items.Add('- maps table not found -');
    finally
      MapConfig_db.free;
    end;
    GB_Progress(1, 0 ,100);
  end;  
  GB_Kind(_('Map-config reading done'));
  form_MapInh(True);
end;
//-------------------------------------------------------------------------------------------------------------------------------
{Refresh Map-config database}
procedure form_MapConfDbRefr(Sender: TObject);
var  
  MapConfig_db        : TSqliteDatabase; // databaze seznamu map 
  MapFileList         : TStringList;
  i                   : integer;
begin
  form_MapInh(False);
  GB_Kind(_('Map-config.xml is reading...'));
  GB_Progress(1, 10 ,100);
  //zalozi databazi seznamu definovanych map v map-config.xml
  if FileExists(MakroPath + 'Data\Map-config.db3') then DeleteFile(MakroPath + 'Data\Map-config.db3');
  MapConfig_db := TSqliteDatabase.Create(MakroPath + 'Data\Map-config.db3');
  try
    MapConfig_db.ExecSQL('CREATE TABLE map_source (key INTEGER PRIMARY KEY AUTOINCREMENT,type STRING,name STRING,storage STRING)');
    MapConfig_db.ExecSQL('CREATE TABLE map_type   (key INTEGER,name STRING,file STRING,mode STRING, PRIMARY KEY(key,name,file,mode))');
  finally
    MapConfig_db.free;
  end;
  //read the orig. config. file from the PocketDrake install dir
  GB_Progress(1, 20 ,100);
  if FileExists(MakroPath + 'Data\map-config-' + PDLang + '.xml') then
    ReadMapConfig(MakroPath + 'Data\map-config-' + PDLang + '.xml')
  else
    ReadMapConfig(MakroPath + 'Data\map-config.xml');
  //List of map-config.xml files from the PocketDrake data dir
  GB_Progress(1, 30 ,100);
  MapFileList  := TStringList.Create;
  try
    FileList(ToCardPath(MapPath), MapFileList);
    for i := (MapFileList.Count - 1) downto 0 do begin     //necha pouze *map-config.xml soubory
      if RegexFind('.*map-config.xml$', LowerCase(MapFileList[i])) then begin
        ReadMapConfig(MapFileList[i]);
      end;
    end;
  finally
    MapFileList.free;
  end;
  form_MapRead(MapForm_btn_Refresh);    //nacte seznam map z databaze map-config.db3
  GB_Clean;
  form_MapInh(True);
end;

//===============================================================================================================================
//===============================================================================================================================
{Kopiruje mapy PC<->PC vcetne podslozek, pouze soubory a cesta dle zadane regex masky a dle typu map}
procedure MapCopy(FromDir: string; ToDir: string; RegexMaskPath: string; RegexMaskFile: string; FileMinSize: LongInt; MapType: string; Caption: string; Storage: string);
var
  Map_db        : TSqliteDatabase; // databaze s mapou 
  Map_table     : TSqliteTable;    // databaze s mapou 
  Files,Queue   : TStringList;
  FilesAll      : TStringList;
  NameDestFile  : string;
  MapDestExists : boolean;
  MapDestSize   : LongInt;
  MapSrcSize    : LongInt;
  NumMapsDone   : Integer;
  n             : Integer;
  x,y,z,s       : String;
  script        : String;
begin
  if not RegexFind('\\$',FromDir) then FromDir := FromDir + '\';
  if not RegexFind('\\$',ToDir)   then ToDir   := ToDir   + '\';
  if (Storage = 'database')       then ToDir   := RegexReplace('\\$', ToDir, '', False);   //pokud je database, pak bez lomitka, bo se tvori _ToDir_.pdmap
  if DirectoryExists(FromDir) then begin
    GB_Caption(Caption);
    GB_Kind(_('files are calculated:') + RegexExtract('[^\\]+\S$',FromDir) + ' "' + RegexMaskFile + '"');
    GB_Value(FromDir + RegexMaskFile);
    Queue    := TStringList.Create;
    Files    := TStringList.Create;
    FilesAll := TStringList.Create;
    try
      Queue.Add(FromDir);
      while (Queue.Count > 0) do begin
        if GB_Test then Break;  //preruseno uzivatelem
        GB_Progress(1, FilesAll.Count ,(FilesAll.Count + 1));
        FileList(Queue[0],Files); Queue.Delete(0);
        for n := 0 to Files.Count-1 do begin
          if RegexFind('\\$',Files[n]) then begin if RegexFind(RegexMaskPath,Files[n]) then Queue.Add(Files[n]);    end
                                       else begin if RegexFind(RegexMaskFile,Files[n]) then FilesAll.Add(Files[n]); end;
        end;
      end;
      GB_Kind(_('files are copied: ') + RegexExtract('[^\\]+\S$',FromDir) + ' "' + RegexMaskFile + '"');
      (*FILESYSTEM*)
      if Storage = 'filesystem' then begin
        for n := 0 to FilesAll.Count-1 do begin
          if GB_Test then Break;  //preruseno uzivatelem
          GB_Progress(1, n ,FilesAll.Count);
          NameDestFile  := ToDir + ReplaceString(FilesAll[n], FromDir, '');
          MakeDirPC(ReplaceString(NameDestFile, RegexExtract('[^\\]+\S$',NameDestFile), ''));
          MapDestExists := FileExists(NameDestFile);
          MapDestSize   := GetFileSize(NameDestFile);
          MapSrcSize    := GetFileSize(FilesAll[n]);
          if (MapSrcSize > FileMinSize) then begin
            if not MapDestExists or (MapType <> 'Ozi') then begin
              CopyFile(FilesAll[n], NameDestFile);
              NumMapsDone := NumMapsDone + 1;
            end
            else if (MapSrcSize > MapDestSize) then begin
              DeleteFile(NameDestFile);
              CopyFile(FilesAll[n], NameDestFile);
              NumMapsDone := NumMapsDone + 1;
            end;
          end;
          if (MapType = 'Geokuk') and MapForm_cb_GeoKuk_Del.Checked then DeleteFile(FilesAll[n]);
        end;
      end
      (*DATABASE*)
      else begin
        if (MapType = 'Geokuk') then Map_db := TSqliteDatabase.Create(ReplaceString(ToDir,'kachle','mapy_cz') + '.pdmap')
                                else Map_db := TSqliteDatabase.Create(ToDir + '.pdmap');
        try
          if not SQLTableExists(Map_db, 'info')  then Map_db.ExecSQL('CREATE TABLE info(minzoom,maxzoom)');
          if not SQLTableExists(Map_db, 'tiles') then Map_db.ExecSQL('CREATE TABLE tiles(x int, y int, z int, s int, image blob, PRIMARY KEY (x,y,z,s))');
          Map_db.ExecSQL('BEGIN TRANSACTION');
          for n := 0 to FilesAll.Count-1 do begin
            if GB_Test then Break;  //preruseno uzivatelem
            GB_Progress(1, n ,FilesAll.Count);
            case MapType of
              'Geokuk' : begin
                script := RegexExtract('\w+\.kachle$', FilesAll[n]);  
                x :=      IntToStr(HexToDec(RegExSubstitute('_[0-9]{1,2}_([0-9a-f]{7}?)_[0-9a-f]{7}\.kachle',    script, '$1')));   
                y :=      IntToStr(HexToDec(RegExSubstitute('_[0-9]{1,2}_[0-9a-f]{7}_([0-9a-f]{7}?)\.kachle',    script, '$1')));   
                z := IntToStr(17 - StrToInt(RegExSubstitute('_([0-9]{1,2}?)_[0-9a-f]{7}_[0-9a-f]{7}\.kachle',    script, '$1')));   
                s :=                        RegExSubstitute('^(.*?)_[0-9]{1,2}_[0-9a-f]{7}_[0-9a-f]{7}\.kachle', script, '$1');   
              end;
              else begin           
                script := RegexExtract('\d+\\\d+\\\d+(\.(png|jpg))$', FilesAll[n]);   
                x :=                        RegExSubstitute('\\(.*?)\\',                  script, '$1');   
                y :=                        RegExSubstitute('\d+\\\d+\\(.*?)\.(png|jpg)', script, '$1');
                z := IntToStr(17 - StrToInt(RegexExtract('^\d+',                          script)));
                s := '0';   
              end;
            end;   
            if (x<>'') and (y<>'') and (z<>'') and (s<>'') then begin
              MapSrcSize  := GetFileSize(FilesAll[n]);
              MapDestSize := 0;
              Map_table := Map_db.GetTable('SELECT * FROM tiles WHERE x="' + x +'" AND y="' + y + '" AND z="' + z + '" AND s="' + s + '"' , false);  //
              try
                if not Map_table.EOF then MapDestSize := Length(Map_table.FieldAsBlobText(4));
              finally
                Map_table.free;
              end;
              if (MapSrcSize > FileMinSize) and ((MapSrcSize > MapDestSize) or (MapType <> 'Ozi')) then begin
                Map_db.AddParamBlobText(':pblob', FileToString(FilesAll[n]));
                Map_db.ExecSQL('INSERT OR REPLACE INTO tiles (x,y,z,s,image) VALUES("' + x +'","' + y + '","' + z + '","' + s + '",:pblob)');      
                NumMapsDone := NumMapsDone + 1;
              end;
            end;
            if (MapType = 'Geokuk') and MapForm_cb_GeoKuk_Del.Checked then DeleteFile(FilesAll[n]);
          end;
          Map_db.ExecSQL('COMMIT');
        finally
          Map_db.free;
        end;  
      end;
      (*XXXXXXXXX*)
      NumCopyImgDone := NumCopyImgDone + NumMapsDone; NumCopyImgAll  := NumCopyImgAll  + FilesAll.Count;
      GB_Kind(_(' .. Copying done: ') + IntToStr(NumMapsDone) + '/' + IntToStr(FilesAll.Count) + _(' maps ')); 
    finally
      Queue.Free; Files.Free; FilesAll.Free;
    end;
    GB_Clean;
  end;
end;
//===============================================================================================================================
//---- MAPC2MAPC ----------------------------------------------------------------------------------------------------------------
//===============================================================================================================================
{kopiruje obsah atlasu vytvorenych pomoci MAPC2MAPC z OziExploreru}
procedure OziAtlCopy(FromDir: string; ToDir: string; Storage: string);
var
   fl, Atlases  : TStringList;
   n : integer;
begin
  if not RegexFind('\\$',FromDir) then FromDir := FromDir + '\';
  if not RegexFind('\\$',ToDir)   then ToDir   := ToDir   + '\';
  if DirectoryExists(FromDir) then begin
    fl       := TStringList.Create;
    Atlases  := TStringList.Create;
    if RegexFind('_atlas\\$',FromDir) then begin
      Atlases.Add(FromDir);
    end
    else begin  
      FileList(FromDir,fl);
      for n := 0 to (fl.Count-1) do if RegexFind('_atlas\\$',fl[n]) then Atlases.Add(fl[n]);
    end;
    n := Atlases.Count;
    GB_Progress(2, 1 ,n);
    NumCopyImgDone := 0; NumCopyImgAll := 0;
    while (Atlases.Count > 0) do begin
      GB_Kind(_('Copying files from: ') + RegexExtract('[^\\]+_atlas', Atlases[0]));
      GB_Progress(2, n-Atlases.Count+1 ,n);
      if GB_Test then Break; //preruseno uzivatelem
      MapCopy(Atlases[0], ToCardPath(ToDir), '\d+\\$', '\d+\.(png|jpg)$', 2000, 'Ozi', _('Offline maps are copied to: ') + ReplaceString(ToDir, MapPath, '') + ' (' + IntToStr(n-Atlases.Count+1) + '/' + IntToStr(n) + ')', Storage);
      Atlases.Delete(0);
    end;
    LogWork(_('= Maps from MAPC2MAPC to PDA transferred') + '(' + IntToStr(NumCopyImgDone) + '/' + IntToStr(NumCopyImgAll) + ')');
    MapForm_lb_ProgressText.Caption := _(' .. Copying done: ') + IntToStr(NumCopyImgDone) + '/' + IntToStr(NumCopyImgAll) + _(' maps '); 
    fl.Free;
    Atlases.Free;
    GB_Clean;
  end;
end;
//-------------------------------------------------------------------------------------------------------------------------------
{Import Maps from MAPC2MAPC}
procedure form_MapImpOzi(Sender: TObject);
var
  Map_ID       : String; 
  Map_Storage  : String; 
  Map_File     : String;
begin
  form_MapInh(False);
  if PDCard then begin
    Map_ID      := RegexExtract('\d+$', MapForm_lb_Map.Items[MapForm_lb_Map.ItemIndex]);
    Map_Storage := RegexExtract('database|filesystem', MapForm_lb_Map.Items[MapForm_lb_Map.ItemIndex]);
    Map_File    := RegexExtract('\S+$', MapForm_lb_MapType.Items[MapForm_lb_MapType.ItemIndex]);
    GB_Caption(_('Offline maps from MAPC2MAPC synchronization'));
    OziMapPath := MapForm_ed_OziPath.Text;
    if OziMapPath <> '' then begin
      SaveIniStrValue('DEFAULT', 'LastOziMapPath', OziMapPath);                                
      GB_Kind(_('files are copying, pleas wait...'));
      OziAtlCopy(OziMapPath, ToCardPath(MapPath + '\' + Map_File), Map_Storage);
    end
    else LogWork(_('# Error: Mapos from ')+RegexExtract('[^\\]+_atlas', OziMapPath)+_(' to PDA not transferred!'));
    GB_Clean;
    MapForm_pb_Track2.Position := 0; 
  end;
  form_MapInh(True);
end;
//-------------------------------------------------------------------------------------------------------------------------------
{OziPath}
procedure form_OziPath(Sender: TObject);
var
  script : String;
begin
  script := SelectDir(OziMapPath, _('Select folder of MAPC2MAPC atlas')+CRLF+
                                  '(' + _('example:') + ' C:\MAPC2MAPC\Maps\CZ_09-29_atlas)');
  if script <> '' then begin   
    OziMapPath              := script;                                 
    MapForm_ed_OziPath.Text := script;
    SaveIniStrValue('DEFAULT', 'LastOziMapPath', OziMapPath);
  end;
end;
//===============================================================================================================================
//---- MobAtlCr -----------------------------------------------------------------------------------------------------------------
//===============================================================================================================================
{Import Maps from MobAtlCr}
procedure form_MapImpMobac(Sender: TObject);
var
  Map_ID       : String; 
  Map_Name     : String; 
  Map_Storage  : String; 
  Map_Type     : String;
  Map_File     : String;
  path : String;
begin
  form_MapInh(False);
  if PDCard then begin
    Map_ID      := RegexExtract('\d+$',                MapForm_lb_Map.Items[MapForm_lb_Map.ItemIndex]);
    Map_Name    := RegexExtract('^.{30}',              MapForm_lb_Map.Items[MapForm_lb_Map.ItemIndex]);
    Map_Storage := RegexExtract('database|filesystem', MapForm_lb_Map.Items[MapForm_lb_Map.ItemIndex]);
    Map_Type    := RegexExtract('^.{16}',              MapForm_lb_MapType.Items[MapForm_lb_MapType.ItemIndex]);
    Map_File    := RegexExtract('\S+$',                MapForm_lb_MapType.Items[MapForm_lb_MapType.ItemIndex]);
    GB_Caption(_('Offline maps from MobileAtlasCreator synchronization'));
    MobAtlCrPath := MapForm_ed_MobacPath.Text;
    if MobAtlCrPath <> '' then begin
      GB_Kind(_('transferring maps...'));
      if DirectoryExists(MobAtlCrPath) then begin
        path := RegexExtract('^\\\w*', '\' + Map_File);
        MakeDirPDA(ToCardPath(MapPath) + path);                                   // pro jistotu v PDA zalozi adresar pro mapy, kdyby jeste nebyl (prikl: '\google')
        if (('\' + Map_File) <> path) then MakeDirPDA(ToCardPath(MapPath) + '\' + Map_File);      // pro jistotu v PDA zalozi adresar pro mapy, kdyby jeste nebyl (prikl: '\google\map')
        MapCopy(MobAtlCrPath, ToCardPath(MapPath) + '\' + Map_File, '\d+\\$', '\d+\.(png|jpg)$', 0, 'Mobac', _('Offline maps from MobileAtlasCreator are synchronized.'), Map_Storage);
      end;
      LogWork(_('= Maps from MobileAtlasCreator to PDA transferred'));
    end
    else LogWork(_('# Error: Mapos from MobileAtlasCreator to PDA not transferred!'));
    GB_Clean;
    MapForm_pb_Track2.Position := 0; 
  end;
  form_MapInh(True);
end;
//-------------------------------------------------------------------------------------------------------------------------------
{MobacPath}
procedure form_MobacPath(Sender: TObject);
var
  script : String;
begin
  script := SelectDir(MobAtlCrPath, _('Select folder of atlas') + ', ' + _('example:')+CRLF+
                                      'C:\MobileAtlasCreator\atlases\MyAtlas_2010-09-03_211537\Google');
  if script <> '' then begin   
    MobAtlCrPath              := script;                                 
    MapForm_ed_MobacPath.Text := script;
    SaveIniStrValue('DEFAULT', 'LastMobAtlCrPath', MobAtlCrPath);
  end;
end;
//===============================================================================================================================
//---- GeoKuk -------------------------------------------------------------------------------------------------------------------
//===============================================================================================================================
{Import Maps from GeoKuk}
procedure form_MapImpGeokuk(Sender: TObject);
var
  Map_ID       : String; 
  Map_Name     : String; 
  Map_Storage  : String; 
  Map_Type     : String;
  Map_File     : String;
  i : Integer;
begin
  form_MapInh(False);
  if PDCard then begin
    Map_ID      := RegexExtract('\d+$',                MapForm_lb_Map.Items[MapForm_lb_Map.ItemIndex]);
    Map_Name    := RegexExtract('^.{30}',              MapForm_lb_Map.Items[MapForm_lb_Map.ItemIndex]);
    Map_Storage := RegexExtract('database|filesystem', MapForm_lb_Map.Items[MapForm_lb_Map.ItemIndex]);
    GB_Caption(_('Offline maps from GeoKuk synchronization'));
    // zjisteni cesty k mapovym kachlim programu GeoKuk
    GB_Kind(_('searching maps path...'));
    if DirectoryExists(SmartPath_GK(GeoKukPath)) then begin
      GB_Kind(_('transferring maps...'));
      MakeDirPDA(ToCardPath(MapPath + '\kachle'));       // pro jistotu v PDA zalozi adresar pro mapy, kdyby jeste nebyl
      NumCopyImgDone := 0; NumCopyImgAll := 0;
      for i := (MapForm_lb_MapType.Items.Count - 1) downto 0 do begin 
        GB_Progress(2, MapForm_lb_MapType.Items.Count - i ,MapForm_lb_MapType.Items.Count);
        if MapForm_lb_MapType.Selected[i] then begin
          Map_Type    := RegexExtract('^.{16}',              MapForm_lb_MapType.Items[i]);
          Map_File    := RegexExtract('\S+$',                MapForm_lb_MapType.Items[i]);
          MapCopy(SmartPath_GK(GeoKukPath), ToCardPath(MapPath + '\kachle'), '\\$', Map_File + '_.*\.kachle', 0, 'Geokuk', _('Offline maps from GeoKuk are synchronized'), Map_Storage);
        end;
      end;
      MapForm_lb_ProgressText.Caption := _(' .. Copying done: ') + IntToStr(NumCopyImgDone) + '/' + IntToStr(NumCopyImgAll) + _(' maps '); 
      LogWork(_('= Maps from GeoKuk to PDA transferred') + '(' + IntToStr(NumCopyImgDone) + '/' + IntToStr(NumCopyImgAll) + ')');
    end
    else begin
      ShowMessage(_('Location of GeoKuk maps failed!')+CRLF+ SmartPath_GK(GeoKukPath));
      LogWork(_('# Error: Mapos from GeoKuk to PDA not transferred!'));
    end;
    GB_Clean;
    MapForm_pb_Track2.Position := 0; 
  end; 
  form_MapInh(True);
end;
//===============================================================================================================================
//===============================================================================================================================
{Stop copying}
procedure form_MapStop(Sender: TObject);
begin
  EventCancel := True;
end;
//-------------------------------------------------------------------------------------------------------------------------------
{Show window - Maps Manager}
procedure form_ShowMapForm(Sender: TObject);
begin
  ReadRegPDA(True, False); // Nacteni nastaveni PocketDrake z registru PDA
  MapForm_ed_PD_disc.Text    := CardPath;
  MapForm_ed_OziPath.Text    := OziMapPath;
  MapForm_ed_MobacPath.Text  := MobAtlCrPath;
  MapForm_ed_GeokukPath.Text := SmartPath_GK(GeoKukPath) + '\';
  form_MapRead(MapForm_btn_Refresh);    //nacte seznam map z databaze map-config.db3
  MapForm.ShowModal;
  GB_Caption(_('Maps manager showed'));
end;
